@@ -13,12 +13,11 @@
 #include "google/protobuf/unittest.pb.h"  // IWYU pragma: keep, used in UNITTEST
 
 #define REFLECTION_TEST RepeatedFieldReflectionTest
-#define UNITTEST_PACKAGE_NAME "protobuf_unittest"
-#define UNITTEST ::protobuf_unittest
-#define UNITTEST_IMPORT ::protobuf_unittest_import
+#define UNITTEST_PACKAGE_NAME "proto2_unittest"
+#define UNITTEST ::proto2_unittest
+#define UNITTEST_IMPORT ::proto2_unittest_import
 
 // Must include after the above macros.
 // clang-format off
-#include "google/protobuf/test_util.inc"
 #include "google/protobuf/repeated_field_reflection_unittest.inc"
 // clang-format on
